/*---------------------------------------------------------------------------*
 *  audioinwrapper.h  *
 *                                                                           *
 *  Copyright 2007, 2008 Nuance Communciations, Inc.                               *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the 'License');          *
 *  you may not use this file except in compliance with the License.         *
 *                                                                           *
 *  You may obtain a copy of the License at                                  *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an 'AS IS' BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. * 
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *                                                                           *
 *---------------------------------------------------------------------------*/

#ifndef __AUDIOINWRAPPER_H__
#define __AUDIOINWRAPPER_H__

#if defined( __cplusplus )
extern "C"
{
#endif

/* -------------------------------------------------------------------------+
 |   C++ FUNCTION WRAPPER                                                   |
 + -------------------------------------------------------------------------*/

int AudioOpen(void);
int AudioClose(void);
int AudioSetInputFormat(int sample_rate, int channel_count);
int AudioRead(short *buffer, int frame_count);
int AudioSetVolume(int stream_type, int volume);
int AudioGetVolume(int stream_type);

#if defined( __cplusplus )
}
#endif

#endif
